@@ -60,12 +60,12 @@ void Office2007Extractor::extract(ExtractionResult* result)
     }
 
     const QStringList rootEntries = rootDir->entries();
-    if (!rootEntries.contains("docProps")) {
+    if (!rootEntries.contains(QStringLiteral("docProps"))) {
         qWarning() << "Invalid document structure (docProps is missing)";
         return;
     }
 
-    const KArchiveEntry* docPropEntry = rootDir->entry("docProps");
+    const KArchiveEntry* docPropEntry = rootDir->entry(QStringLiteral("docProps"));
     if (!docPropEntry->isDirectory()) {
         qWarning() << "Invalid document structure (docProps is not a directory)";
         return;
@@ -74,14 +74,14 @@ void Office2007Extractor::extract(ExtractionResult* result)
     const KArchiveDirectory* docPropDirectory = dynamic_cast<const KArchiveDirectory*>(docPropEntry);
     const QStringList docPropsEntries = docPropDirectory->entries();
 
-    if (docPropsEntries.contains("core.xml")) {
-        QDomDocument coreDoc("core");
-        const KArchiveFile* file = static_cast<const KArchiveFile*>(docPropDirectory->entry("core.xml"));
+    if (docPropsEntries.contains(QStringLiteral("core.xml"))) {
+        QDomDocument coreDoc(QStringLiteral("core"));
+        const KArchiveFile* file = static_cast<const KArchiveFile*>(docPropDirectory->entry(QStringLiteral("core.xml")));
         coreDoc.setContent(file->data());
 
         QDomElement docElem = coreDoc.documentElement();
 
-        QDomElement elem = docElem.firstChildElement("dc:description");
+        QDomElement elem = docElem.firstChildElement(QStringLiteral("dc:description"));
         if (!elem.isNull()) {
             QString str = elem.text();
             if (!str.isEmpty()) {
@@ -89,7 +89,7 @@ void Office2007Extractor::extract(ExtractionResult* result)
             }
         }
 
-        elem = docElem.firstChildElement("dc:subject");
+        elem = docElem.firstChildElement(QStringLiteral("dc:subject"));
         if (!elem.isNull()) {
             QString str = elem.text();
             if (!str.isEmpty()) {
@@ -97,7 +97,7 @@ void Office2007Extractor::extract(ExtractionResult* result)
             }
         }
 
-        elem = docElem.firstChildElement("dc:title");
+        elem = docElem.firstChildElement(QStringLiteral("dc:title"));
         if (!elem.isNull()) {
             QString str = elem.text();
             if (!str.isEmpty()) {
@@ -105,7 +105,7 @@ void Office2007Extractor::extract(ExtractionResult* result)
             }
         }
 
-        elem = docElem.firstChildElement("dc:creator");
+        elem = docElem.firstChildElement(QStringLiteral("dc:creator"));
         if (!elem.isNull()) {
             QString str = elem.text();
             if (!str.isEmpty()) {
@@ -113,7 +113,7 @@ void Office2007Extractor::extract(ExtractionResult* result)
             }
         }
 
-        elem = docElem.firstChildElement("dc:language");
+        elem = docElem.firstChildElement(QStringLiteral("dc:language"));
         if (!elem.isNull()) {
             QString str = elem.text();
             if (!str.isEmpty()) {
@@ -121,7 +121,7 @@ void Office2007Extractor::extract(ExtractionResult* result)
             }
         }
 
-        elem = docElem.firstChildElement("dcterms:created");
+        elem = docElem.firstChildElement(QStringLiteral("dcterms:created"));
         if (!elem.isNull()) {
             QString str = elem.text();
             QDateTime dt = dateTimeFromString(elem.text());
@@ -130,7 +130,7 @@ void Office2007Extractor::extract(ExtractionResult* result)
             }
         }
 
-        elem = docElem.firstChildElement("cp:keywords");
+        elem = docElem.firstChildElement(QStringLiteral("cp:keywords"));
         if (!elem.isNull()) {
             QString str = elem.text();
             if (!str.isEmpty()) {
@@ -139,17 +139,17 @@ void Office2007Extractor::extract(ExtractionResult* result)
         }
     }
 
-    if (docPropsEntries.contains("app.xml")) {
-        QDomDocument appDoc("app");
-        const KArchiveFile* file = static_cast<const KArchiveFile*>(docPropDirectory->entry("app.xml"));
+    if (docPropsEntries.contains(QStringLiteral("app.xml"))) {
+        QDomDocument appDoc(QStringLiteral("app"));
+        const KArchiveFile* file = static_cast<const KArchiveFile*>(docPropDirectory->entry(QStringLiteral("app.xml")));
         appDoc.setContent(file->data());
 
         QDomElement docElem = appDoc.documentElement();
 
         // According to the ontologies only Documents can have a wordCount and pageCount
         const QString mimeType = result->inputMimetype();
-        if (mimeType == QStringLiteral("application/vnd.openxmlformats-officedocument.wordprocessingml.document")) {
-            QDomElement elem = docElem.firstChildElement("Pages");
+        if (mimeType == QLatin1String("application/vnd.openxmlformats-officedocument.wordprocessingml.document")) {
+            QDomElement elem = docElem.firstChildElement(QStringLiteral("Pages"));
             if (!elem.isNull()) {
                 bool ok = false;
                 int pageCount = elem.text().toInt(&ok);
@@ -158,7 +158,7 @@ void Office2007Extractor::extract(ExtractionResult* result)
                 }
             }
 
-            elem = docElem.firstChildElement("Words");
+            elem = docElem.firstChildElement(QStringLiteral("Words"));
             if (!elem.isNull()) {
                 bool ok = false;
                 int wordCount = elem.text().toInt(&ok);
@@ -168,7 +168,7 @@ void Office2007Extractor::extract(ExtractionResult* result)
             }
         }
 
-        QDomElement elem = docElem.firstChildElement("Application");
+        QDomElement elem = docElem.firstChildElement(QStringLiteral("Application"));
         if (!elem.isNull()) {
             QString app = elem.text();
             if (!app.isEmpty()) {
@@ -182,13 +182,13 @@ void Office2007Extractor::extract(ExtractionResult* result)
     //
     bool extractPlainText = (result->inputFlags() & ExtractionResult::ExtractPlainText);
 
-    if (rootEntries.contains("word")) {
+    if (rootEntries.contains(QStringLiteral("word"))) {
         result->addType(Type::Document);
 
         if (!extractPlainText)
             return;
 
-        const KArchiveEntry* wordEntry = rootDir->entry("word");
+        const KArchiveEntry* wordEntry = rootDir->entry(QStringLiteral("word"));
         if (!wordEntry->isDirectory()) {
             qWarning() << "Invalid document structure (word is not a directory)";
             return;
@@ -197,22 +197,22 @@ void Office2007Extractor::extract(ExtractionResult* result)
         const KArchiveDirectory* wordDirectory = dynamic_cast<const KArchiveDirectory*>(wordEntry);
         const QStringList wordEntries = wordDirectory->entries();
 
-        if (wordEntries.contains("document.xml")) {
-            QDomDocument appDoc("document");
-            const KArchiveFile* file = static_cast<const KArchiveFile*>(wordDirectory->entry("document.xml"));
+        if (wordEntries.contains(QStringLiteral("document.xml"))) {
+            QDomDocument appDoc(QStringLiteral("document"));
+            const KArchiveFile* file = static_cast<const KArchiveFile*>(wordDirectory->entry(QStringLiteral("document.xml")));
 
             extractTextWithTag(file->createDevice(), QStringLiteral("w:t"), result);
         }
     }
 
-    else if (rootEntries.contains("xl")) {
+    else if (rootEntries.contains(QStringLiteral("xl"))) {
         result->addType(Type::Document);
         result->addType(Type::Spreadsheet);
 
         if (!extractPlainText)
             return;
 
-        const KArchiveEntry* xlEntry = rootDir->entry("xl");
+        const KArchiveEntry* xlEntry = rootDir->entry(QStringLiteral("xl"));
         if (!xlEntry->isDirectory()) {
             qWarning() << "Invalid document structure (xl is not a directory)";
             return;
@@ -222,14 +222,14 @@ void Office2007Extractor::extract(ExtractionResult* result)
         extractTextFromFiles(xlDirectory, result);
     }
 
-    else if (rootEntries.contains("ppt")) {
+    else if (rootEntries.contains(QStringLiteral("ppt"))) {
         result->addType(Type::Document);
         result->addType(Type::Presentation);
 
         if (!extractPlainText)
             return;
 
-        const KArchiveEntry* pptEntry = rootDir->entry("ppt");
+        const KArchiveEntry* pptEntry = rootDir->entry(QStringLiteral("ppt"));
         if (!pptEntry->isDirectory()) {
             qWarning() << "Invalid document structure (ppt is not a directory)";
             return;
@@ -267,7 +267,7 @@ void Office2007Extractor::extractTextFromFiles(const KArchiveDirectory* archiveD
             continue;
         }
 
-        if (!entryName.endsWith(".xml"))
+        if (!entryName.endsWith(QLatin1String(".xml")))
             continue;
 
         const KArchiveFile* file = static_cast<const KArchiveFile*>(entry);
